use binding::{CInt, CLong};



/// The type used for seconds in the time structures.
pub type Seconds = CLong;



/// The local time of the system. This can be used
/// to get more specific calendar type information.
#[derive(Copy, Clone)]
#[repr(C)]
pub struct LocalTime
{
   /// Seconds [0-60]  **Note** 1 leap second.
   second: CInt,

   /// Minutes [0-59].
   minute: CInt,

   /// Hours [0-23].
   hour: CInt,

   /// Day of the month [1-31].
   day_of_month: CInt,

   /// Month of the year [0-11].
   month: CInt,

   /// Years since 1900.
   year: CInt,

   /// Days since Sunday [0-6].
   day_of_week: CInt,

   /// Days since January 1 [0-365].
   day_of_year: CInt,

   /// DST [-1/0/1]. Greater than zero if DST is in effect,
   /// zero if DST is not in effect, and less than zero if
   /// the information is not available.
   is_dst: CInt,
}



#[link(name="c")]
extern
{
   /// Uses the value pointed by time to fill a LocalTime structure with
   /// the values that represent the corresponding time, expressed
   /// for the local timezone.
   pub fn localtime(time: *const Seconds) -> *const LocalTime;
}
